<?php
/**
 * Register an account when using OAuth.
 * 
 * @param  string    $provider 
 * @param  string    $openID 
 * @access public
 * @return void
 */
public function registerOauthAccount($provider, $openID)
{
    if($this->post->password1) $this->checkPassword();

    $user = fixer::input('post')
        ->setForce('join', helper::now())
        ->setForce('last', helper::now())
        ->setForce('visits', 1)
        ->setIF($this->cookie->referer != '', 'referer', $this->cookie->referer)
        ->setIF($this->cookie->referer == '', 'referer', '')
        ->remove('admin, ip')
        ->get();

    $user->password = $this->createPassword(md5(mt_rand()), $openID);
    if($this->post->password1) $user->password = $this->createPassword($this->post->password1, $user->account); 
    if(!isset($user->password1)) $this->config->user->require->register = 'account';

    $oldUser = $this->getByOpenID($openID, $provider);
    if($oldUser)
    {
        $this->dao->update(TABLE_USER)->data($user, $skip = 'password1,password2')
            ->autoCheck()
            ->batchCheck($this->config->user->require->register, 'notempty')
            ->check('account', 'unique')
            ->check('account', 'account')
            ->checkIF(isset($user->email), 'email', 'unique')
            ->checkIF(isset($user->email), 'email', 'email')
            ->where('id')->eq($oldUser->id)
            ->exec();

        $this->dao->update(TABLE_MESSAGE)->set('account')->eq($user->account)->where('account')->eq($oldUser->account)->exec();
        $this->dao->update(TABLE_MESSAGE)->set('to')->eq($user->account)->where('account')->eq($oldUser->account)->exec();
        $this->dao->update(TABLE_THREAD)->set('author')->eq($user->account)->where('author')->eq($oldUser->account)->exec();
        $this->dao->update(TABLE_THREAD)->set('repliedBy')->eq($user->account)->where('repliedBy')->eq($oldUser->account)->exec();
        $this->dao->update(TABLE_REPLY)->set('author')->eq($user->account)->where('author')->eq($oldUser->account)->exec();
        $this->dao->update(TABLE_CATEGORY)->set('postedBy')->eq($user->account)->where('postedBy')->eq($oldUser->account)->exec();
        $this->dao->update(TABLE_ADDRESS)->set('account')->eq($user->account)->where('account')->eq($oldUser->account)->exec();
        $this->dao->update(TABLE_CART)->set('account')->eq($user->account)->where('account')->eq($oldUser->account)->exec();
        $this->dao->update(TABLE_ORDER)->set('account')->eq($user->account)->where('account')->eq($oldUser->account)->exec();
        $this->dao->update(TABLE_SITE)->set('account')->eq($user->account)->where('account')->eq($oldUser->account)->exec();
    }
    else
    { 
        $this->dao->insert(TABLE_USER)->data($user, $skip = 'password1,password2')
            ->autoCheck()
            ->batchCheck($this->config->user->require->register, 'notempty')
            ->check('account', 'unique')
            ->check('account', 'account')
            ->check('email', 'unique')
            ->check('email', 'email')
            ->exec();
    }

    if(dao::isError()) return false;
    return $this->bindOAuthAccount($this->post->account, $provider, $openID);
}
